@@ -16,10 +16,16 @@
  *)
 
 module Client = struct
-  let default_ctx = `Ssl_not_available
+  type verify = { hostname : bool; ip : bool }
+
+  let default_verify = { hostname = true; ip = true }
+
+  type context = Ssl_not_available
+
+  let default_ctx = Ssl_not_available
   let create_ctx ?certfile:_ ?keyfile:_ ?password:_ () = default_ctx
 
-  let connect ?(ctx = default_ctx) ?src:_ ?hostname:_ _sa =
+  let connect ?(ctx = default_ctx) ?src:_ ?hostname:_ ?ip:_ ?verify:_ _sa =
     ignore ctx;
     Lwt.fail_with "Ssl not available"
 end
